#!/bin/sh
#
# @(#) Fibranet NSP, SL
# Copyright (C) 2005-2006 by Jordi Sanfeliu <admin@fibranet.cat>
#
# Install shell-script for Monitorix
#

show_paths() {
	echo
	echo "The following is a list of the default paths where to install the Monitorix"
	echo "components:"
	echo
	echo "	1 - $SBIN"
	echo "	2 - $ETC"
	echo "	3 - $INIT"
	echo "	4 - $LIB"
	echo "	5 - $DOC"
	echo "	6 - $HTDOCS"
	echo "	7 - $CGIBIN"
	echo
	echo -n "	Please type ENTER if all it's correct: "
	read path
}

OS=`uname -s`

echo
echo "Welcome to Monitorix v0.8.2 installation process."
echo

case $OS in
	Linux)
		echo "The install script has detected that this is a $OS operating system."
		echo
		OK=0
		while [ $OK -eq 0 ] ; do
		echo "Currently Monitorix supports only the following $OS distributions:"
		echo "	1 - RedHat or Fedora Core Linux"
		echo "	2 - Generic GNU/Linux"
		echo
		echo -n "	Please select your option: "
		read distro
		case $distro in
			1)
				echo
				echo "Please don't use tar.gz files on RedHat or Fedora Core distributions, they"
				echo "offer a better way to install packages".
				echo "Please, go to http://www.monitorix.org/ and download your RPM package."
				echo
				echo "To keep your system clean, this script won't continue."
				echo
				exit 0
				;;

			2)
				SBIN="/usr/local/sbin"
				ETC="/usr/local/etc"
				INIT="/usr/local/etc/rc.d"
				LIB="/usr/local/lib"
				DOC="/usr/local/share"
				HTDOCS="/usr/local/www/data"
				CGIBIN="/usr/local/www/cgi-bin"
				PORTS="${OS}-Generic"
				show_paths
				OK=1
				;;

			*)
				echo "Bad option!. Try again please."
				echo
				;;
		esac
		done
		;;

	FreeBSD)
		echo "The install script has detected that this is a $OS operating system."
		SBIN="/usr/local/sbin"
		ETC="/usr/local/etc"
		INIT="/usr/local/etc/rc.d"
		LIB="/usr/local/lib"
		DOC="/usr/local/share"
		HTDOCS="/usr/local/www/data"
		CGIBIN="/usr/local/www/cgi-bin"
		PORTS="$OS"
		show_paths
		;;

	*)
		echo
		echo "Sorry. Your operating system \"$OS\" is not supported right now."
		echo "Please contact to Jordi Sanfeliu <jordi@fibranet.cat> if you are interested"
		echo "to start the portability process together."
		echo
		exit 1
		;;

esac

echo
echo "Last chance to stop the installation."
OK=0
while [ $OK -eq 0 ] ; do
echo -n "Are you sure to install Monitorix on the paths shown? [y/n]: "
read sure
case $sure in
	[nN])
		echo
		echo "Aborting installation."
		exit 1
		;;

	[yY])
		echo
		echo "Starting installation."
		OK=1
		;;

	*)
		;;
esac
done

echo "Copying updater script to $SBIN directory"
echo "monitorix.pl"
cp monitorix.pl $SBIN
echo

echo "Copying configuration file to $ETC directory"
echo "monitorix.conf"
cp monitorix.conf $ETC
echo

echo "Copying init script to $INIT directory"
echo "ports/${PORTS}/monitorix.init"
cp ports/${PORTS}/monitorix.init $INIT/monitorix.sh
echo

echo "Copying reports files to $LIB directory"
echo "reports/"
cp -r reports $LIB/monitorix/
echo

echo "Copying documentation files to $DOC directory"
echo "Changelog Configuration.help COPYING monitorix-apache.conf monitorix.spec README"
mkdir -p $DOC/monitorix
cp Changelog Configuration.help COPYING monitorix-apache.conf monitorix.spec README $DOC/monitorix/
echo

echo "Copying html files to $HTDOCS directory"
echo "envelope.png logo_bot_black.png logo_bot_white.png logo_top.jpg"
mkdir -p $HTDOCS/monitorix/imgs
chmod 777 $HTDOCS/monitorix/imgs
cp envelope.png logo_bot_black.png logo_bot_white.png logo_top.jpg $HTDOCS/monitorix
echo

echo "Copying cgi-bin files to $CGIBIN directory"
echo "monitorix.cgi localhost.cgi"
mkdir -p $CGIBIN/monitorix
cp monitorix.cgi $CGIBIN
cp localhost.cgi $CGIBIN/monitorix
echo

echo "---------------------------------------------------------------------"
echo
echo "Installation succesfully finished."
echo
echo "Now you have to edit the configuration file $ETC/monitorix.conf"
echo "in order to setup correctly Monitorix to your operating system."
echo
echo "Then you'll can start Monitorix executing the init script:"
echo
echo "$INIT/monitorix.sh [start|stop|status]"
echo
echo "and finally go to http://localhost/monitorix/ to see the results."
echo
exit 0

